@@ -45,12 +45,17 @@ async def ctftime_scraper(url,session):
 
     #Find writeup content and format it
     writeup_html = soup.find_all('div',{'class':'well'})
-    f.write(h.handle(writeup_html[-1].prettify()))
+    if len(writeup_html > 1):
+        f.write(h.handle(writeup_html[-1].prettify()))
     
     f.close()
-
-    if re.match('https?:\/\/github.com\/.*',writeup_html[-1].a['href']):
-        markdwn = await github_scraper(writeup_html[-1].a['href'])
+    if writeup_html[-1].a:
+        if re.match('https?:\/\/github.com\/.*',writeup_html[-1].a['href']):
+            markdwn = await github_scraper(writeup_html[-1].a['href'])
+        else:
+            markdwn = formatter(writeup_html[0])
+    elif re.search("Original writeup",writeup_html[0].text) and re.match('https?:\/\/github.com\/.*',writeup_html[0].a['href']):
+        markdwn = await github_scraper(writeup_html[0].a['href'])
     else:
         markdwn = formatter(writeup_html[0])
     
@@ -59,4 +64,5 @@ async def ctftime_scraper(url,session):
     if markdwn:
         f.write(markdwn)
     f.close()
-    print("Writeup saved in {}".format(d))
\ No newline at end of file
+    print("Writeup for {} saved in {}".format(heading.h2.text.strip(),d))
+    
